'use client'

import { useState, useEffect } from 'react'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { FiUsers, FiGrid, FiClock, FiTrendingUp, FiCoffee, FiPlus } from 'react-icons/fi'
import Link from 'next/link'
import { TableStatus, getStatusColor, getStatusText } from '@/config/tableStatus'
import { tableService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { useStatusStore } from '@/store/useStatusStore'

// Table interface'i oluşturun
interface Table {
  id: number
  name: string
  status: 'active' | 'empty' | 'reserved' | 'waiting'
  items: number
  total: number
  duration?: string // opsiyonel olarak ekleyelim
}

export default function DashboardPage() {
  const { user } = useUser()
  const [tables, setTables] = useState<Table[]>([])
  const checkStatus = useStatusStore((state: any) => state.checkStatus)
  const setOnStatusUpdate = useStatusStore((state: any) => state.setOnStatusUpdate)

  const fetchTables = async () => {
    try {
      const response = await tableService.index(user?.token || '')
      const tablesWithDetails = await Promise.all(
        response.data.tables.map(async (table: any) => {
          try {
            const orderResponse = await tableService.orderDetails(table.id.toString(), user?.token || '')
            return {
              ...table,
              status: table.status as 'active' | 'empty' | 'reserved' | 'waiting',
              items: orderResponse.data.order?.order_items?.length || 0,
              total: orderResponse.data.table?.total_price || 0
            }
          } catch (err) {
            return {
              ...table,
              status: 'empty',
              items: 0,
              total: 0
            }
          }
        })
      )
      setTables(tablesWithDetails)
    } catch (err) {
      //  console.error('Masalar yüklenirken hata:', err)
    }
  }

  // Status kontrolünden sonra tabloyu yenile
  useEffect(() => {
    setOnStatusUpdate(fetchTables)
    return () => setOnStatusUpdate(() => { })
  }, [])

  // Status kontrolü için interval
  useEffect(() => {
    if (!user?.token) return

    // İlk kontrol
    checkStatus(user?.token || '')

    // 15 dakikada bir kontrol
    const interval = setInterval(() => {
      checkStatus(user?.token || '')
    }, 15 * 60 * 1000) // 15 dakika

    return () => clearInterval(interval)
  }, [user?.token])

  // İlk yükleme
  useEffect(() => {
    fetchTables()
    setTimeout(() => {
    }, 10000);
  }, [user?.token])

  return (
    <DashboardLayout>
      <div className="space-y-6">
        {/* İstatistik Kartları */}

        {/* Masa Kartları */}
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <div className="flex items-center justify-between">
              <h2 className="text-xl font-bold text-slate-800 dark:text-white">
                Masalar
              </h2>
              {user?.role == 'admin' && (
                <Link
                  href="/dashboard/tables/add"
                  className="inline-flex items-center gap-2 px-4 py-2 text-sm font-medium 
                         text-white bg-gradient-to-r from-fuchsia-500 to-purple-600 
                         rounded-xl hover:opacity-90 transition-all"
                >
                  + Yeni Masa
                </Link>
              )}
            </div>
          </div>
          <div className="p-6">
            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-4">
              {tables.map((table) => (
                <div
                  key={table.id}
                  className="group relative bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                           border border-slate-200/50 dark:border-slate-700/50 
                           rounded-2xl p-6 shadow-lg"
                >
                  {/* Status Badge - Yeni pozisyon */}
                  <div className="absolute -top-3 right-4">
                    <span className={`inline-block px-3 py-1 rounded-full text-xs font-medium shadow-sm ${getStatusColor(table.status)}`}>
                      {getStatusText(table.status)}
                    </span>
                  </div>

                  {/* Masa Başlığı ve İkon */}
                  <div className="flex items-center gap-4 mb-6">
                    <div className="w-12 h-12 rounded-xl bg-gradient-to-r from-fuchsia-500 to-purple-600 
                                flex items-center justify-center shadow-lg">
                      <FiGrid className="w-6 h-6 text-white" />
                    </div>
                    <div>
                      <h3 className="text-lg font-semibold text-slate-800 dark:text-white">
                        {table.name}
                      </h3>
                    </div>
                  </div>

                  {/* Detaylar */}
                  <div className="space-y-3">
                    <div className="flex justify-between items-center p-3 rounded-xl 
                                bg-slate-50/50 dark:bg-slate-700/50">
                      <span className="text-sm font-medium text-slate-600 dark:text-slate-300">
                        Ürün Sayısı
                      </span>
                      <span className="text-sm font-bold text-slate-700 dark:text-slate-200 
                                   bg-white dark:bg-slate-600 px-3 py-1.5 rounded-lg">
                        {table.items} ürün
                      </span>
                    </div>
                    <div className="flex justify-between items-center p-3 rounded-xl 
                                bg-slate-50/50 dark:bg-slate-700/50">
                      <span className="text-sm font-medium text-slate-600 dark:text-slate-300">
                        Toplam Tutar
                      </span>
                      <span className="text-sm font-bold text-slate-700 dark:text-slate-200 
                                   bg-white dark:bg-slate-600 px-3 py-1.5 rounded-lg">
                        ₺{table.total}
                      </span>
                    </div>
                  </div>

                  {/* Sipariş Gir Butonu */}
                  <Link
                    href={`/dashboard/tables/${table.id}/order`}
                    className="w-full mt-6 px-4 py-3 text-sm font-medium text-white 
                            bg-gradient-to-r from-fuchsia-500 to-purple-600
                            rounded-xl hover:opacity-90 transition-all 
                            flex items-center justify-center gap-2"
                  >
                    <FiPlus className="w-4 h-4" />
                    Sipariş Gir
                  </Link>
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </DashboardLayout>
  )
} 